#!/usr/bin/env python
# To use:
#       python setup.py install
#

import distutils, os
from distutils.core import setup, Extension

if os.name == 'posix':
    mssql = '/opt/sybase'
    mssql_libs = [ 'sybdb' ]
    mxdatetime_incdir = os.path.join(os.environ['HOME'],
                                     'download/DateTime/mxDateTime')
elif os.name == 'nt':
    mssql = 'd:/mssql/dblib'
    mssql_libs = [ 'ntwdblib' ]
    mxdatetime_incdir = 'd:/download/DateTime/mxDateTime'
else:
    import sys
    sys.stderr.write(
        'Sorry, I do not know how to build on this platform.\n'
        '\n'
        'Please edit setup.py and add platform specific settings.  If you\n'
        'figure out how to get it working for your platform, please send\n'
        'mail to djc@object-craft.com.au so you can help other people.\n')
    sys.exit(1)

mssql_incdir = os.path.join(mssql, 'include')
mssql_libdir = os.path.join(mssql, 'lib')

# The version is set in Lib/numeric_version.py

setup (name = "MSSQL",
       version = "0.01",
       maintainer = "Dave Cole",
       maintainer_email = " djc@object-craft.com.au",
       description = "MS SQL Server Extension to Python",
       url = "http://www.object-craft.com.au/projects/mssql/",
       py_modules = ['MSSQL'],
       include_dirs = [mssql_incdir, mxdatetime_incdir],
       ext_modules = [
           Extension('mssqldb',
                     ['mssqldb.c', 'loginrec.c', 'dbproc.c', 'databuf.c',
                      'numeric.c', 'datetime.c', 'money.c'],
                     libraries = mssql_libs,
                     library_dirs = [mssql_libdir]
                     )
           ],
       )

